@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -51,7 +51,7 @@ void Prefix::fixPrefixPath(){
     query.clear();
 }
 
-QString Prefix::getId(const QString prefix_name) const{
+QString Prefix::getId(const QString &prefix_name) const{
     QString value;
     QSqlQuery query;
 
@@ -74,7 +74,7 @@ QString Prefix::getId(const QString prefix_name) const{
     return value;
 }
 
-QString Prefix::getPath(const QString prefix_name) const{
+QString Prefix::getPath(const QString &prefix_name) const{
     QString value;
 
     if (prefix_name == "Default"){
@@ -105,7 +105,7 @@ QString Prefix::getPath(const QString prefix_name) const{
     return value;
 }
 
-QString Prefix::getName(const QString prefix_path) const{
+QString Prefix::getName(const QString &prefix_path) const{
     QString value;
     QSqlQuery query;
     query.prepare("SELECT name FROM prefix WHERE path=:prefix_path");
@@ -123,7 +123,7 @@ QString Prefix::getName(const QString prefix_path) const{
     return value;
 }
 
-QHash<QString,QString> Prefix::getByName(const QString prefix_name) const{
+QHash<QString,QString> Prefix::getByName(const QString &prefix_name) const{
     QHash<QString,QString> values;
 
     QSqlQuery query;
@@ -170,7 +170,7 @@ QHash<QString,QString> Prefix::getByName(const QString prefix_name) const{
     return values;
 }
 
-QString Prefix::getMountPoint(const QString prefix_name) const{
+QString Prefix::getMountPoint(const QString &prefix_name) const{
     QString value;
     QSqlQuery query;
 
@@ -189,7 +189,7 @@ QString Prefix::getMountPoint(const QString prefix_name) const{
     return value;
 }
 
-QChar Prefix::getMountPointWindrive(const QString prefix_name) const{
+QChar Prefix::getMountPointWindrive(const QString &prefix_name) const{
     QString value;
     QSqlQuery query;
 
@@ -235,7 +235,7 @@ bool Prefix::updateQuery(QSqlQuery *sqlQuery) const{
     return true;
 }
 
-bool Prefix::delByName(const QString prefix_name) const{
+bool Prefix::delByName(const QString &prefix_name) const{
     QSqlQuery query;
     query.prepare("DELETE FROM prefix WHERE id=(SELECT id FROM prefix WHERE name=:prefix_name )");
     query.bindValue(":prefix_name", prefix_name);
@@ -247,9 +247,9 @@ bool Prefix::delByName(const QString prefix_name) const{
     return true;
 }
 
-bool Prefix::addPrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString arch, const QString mountpoint_windrive, const QString run_string, const QString version_id) const{
+bool Prefix::addPrefix(const QString &prefix_name, const QString &prefix_path, const QString &wine_exec, const QString &wine_server, const QString &wine_loader, const QString &wine_dllpath, const QString &cdrom_mount, const QString &arch, const QString &mountpoint_windrive, const QString &run_string, const QString &version_id) const{
     QSqlQuery query;
-        query.prepare("INSERT INTO prefix(name, path, wine_exec, wine_server, wine_loader, wine_dllpath, cdrom_mount, arch, mountpoint_windrive, run_string, version_id) VALUES(:prefix_name, :prefix_path, :wine_exec, :wine_server, :wine_loader, :wine_dllpath, :cdrom_mount, :arch, :mountpoint_windrive, :run_string, :version_id);");
+    query.prepare("INSERT INTO prefix(name, path, wine_exec, wine_server, wine_loader, wine_dllpath, cdrom_mount, arch, mountpoint_windrive, run_string, version_id) VALUES(:prefix_name, :prefix_path, :wine_exec, :wine_server, :wine_loader, :wine_dllpath, :cdrom_mount, :arch, :mountpoint_windrive, :run_string, :version_id);");
 
     query.bindValue(":prefix_name", prefix_name);
 
@@ -321,9 +321,9 @@ bool Prefix::addPrefix(const QString prefix_name, const QString prefix_path, con
     return true;
 }
 
-bool Prefix::updatePrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString old_prefix_name, const QString arch, const QString mountpoint_windrive, const QString run_string, const QString version_id) const{
+bool Prefix::updatePrefix(const QString &prefix_name, const QString &prefix_path, const QString &wine_exec, const QString &wine_server, const QString &wine_loader, const QString &wine_dllpath, const QString &cdrom_mount, const QString &old_prefix_name, const QString &arch, const QString &mountpoint_windrive, const QString &run_string, const QString &version_id) const{
     QSqlQuery query;
-        query.prepare("UPDATE prefix SET wine_dllpath=:wine_dllpath, wine_loader=:wine_loader, wine_server=:wine_server, wine_exec=:wine_exec, cdrom_mount=:cdrom_mount, arch=:arch, name=:prefix_name, mountpoint_windrive=:mountpoint_windrive, path=:prefix_path, run_string=:run_string, version_id=:version_id WHERE name=:old_prefix_name");
+    query.prepare("UPDATE prefix SET wine_dllpath=:wine_dllpath, wine_loader=:wine_loader, wine_server=:wine_server, wine_exec=:wine_exec, cdrom_mount=:cdrom_mount, arch=:arch, name=:prefix_name, mountpoint_windrive=:mountpoint_windrive, path=:prefix_path, run_string=:run_string, version_id=:version_id WHERE name=:old_prefix_name");
 
     query.bindValue(":prefix_name", prefix_name);
     query.bindValue(":old_prefix_name", old_prefix_name);
@@ -396,7 +396,7 @@ bool Prefix::updatePrefix(const QString prefix_name, const QString prefix_path,
     return true;
 }
 
-bool Prefix::isExistsByName(const QString prefix_name) const{
+bool Prefix::isExistsByName(const QString &prefix_name) const{
     QSqlQuery query;
     query.prepare("SELECT id FROM prefix WHERE name=:prefix_name");
     query.bindValue(":prefix_name", prefix_name);
