@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -42,44 +42,44 @@
 class Prefix
 {
 
-  public:
-     /*! \brief This is calss constructor.
+public:
+    /*! \brief This is class constructor.
       */
-      Prefix();
+    Prefix();
 
-     /*! \brief This function gets all table fields by prefix id key value from table.
+    /*! \brief This function gets all table fields by prefix id key value from table.
       *
       * \param  prefix_id Prefix id key value.
       * \return Return a list of table fields value or -1 on error.
       */
-      QHash<QString,QString> getByName(const QString prefix_name) const;
-      QString getMountPoint(const QString prefix_name) const;
-      QChar getMountPointWindrive(const QString prefix_name) const;
-      QStringList getPrefixList(void) const;
+    QHash<QString,QString> getByName(const QString &prefix_name) const;
+    QString getMountPoint(const QString &prefix_name) const;
+    QChar getMountPointWindrive(const QString &prefix_name) const;
+    QStringList getPrefixList(void) const;
 
-     /*! \brief This function gets prefix id by name.
+    /*! \brief This function gets prefix id by name.
       *
       * \param  prefix_name    A prefix name value.
       * \return Return prefix id.
       */
-     QString getId(const QString prefix_name) const;
+    QString getId(const QString &prefix_name) const;
 
-     /*! \brief This function gets prefix path by name.
+    /*! \brief This function gets prefix path by name.
       *
       * \param  prefix_name    A prefix name value.
       * \return Return prefix path.
       */
-      QString getPath(const QString prefix_name) const;
-      QString getName(const QString prefix_path) const;
+    QString getPath(const QString &prefix_name) const;
+    QString getName(const QString &prefix_path) const;
 
-     /*! \brief This function deletes all prefix fields by prefix_name keys value from table.
+    /*! \brief This function deletes all prefix fields by prefix_name keys value from table.
       *
       * \param  prefix_name    A prefix name value.
       * \return Return true on success.
       */
-      bool delByName(const QString prefix_name) const;
+    bool delByName(const QString &prefix_name) const;
 
-     /*! \brief This function deletes all prefix fields by prefix_name keys value from table.
+    /*! \brief This function deletes all prefix fields by prefix_name keys value from table.
       *
       * \param  prefix_name    A prefix name value.
       * \param  prefix_path    A prefix path value.
@@ -90,16 +90,26 @@ class Prefix
       * \param  cdrom_mount    A cdrom mount directory.
       * \return Return true on success.
       */
-      bool addPrefix(const QString prefix_name, const QString prefix_path="", const QString wine_exec="", const QString wine_server="", const QString wine_loader="", const QString wine_dllpath="", const QString cdrom_mount="", const QString arch="", const QString mountpoint_windrive="", const QString run_string="", const QString version_id="") const;
+    bool addPrefix(const QString &prefix_name,
+                   const QString &prefix_path="",
+                   const QString &wine_exec="",
+                   const QString &wine_server="",
+                   const QString &wine_loader="",
+                   const QString &wine_dllpath="",
+                   const QString &cdrom_mount="",
+                   const QString &arch="",
+                   const QString &mountpoint_windrive="",
+                   const QString &run_string="",
+                   const QString &version_id="") const;
 
-     /*! \brief This function check is reccord exists by prefix name or not.
+    /*! \brief This function check is reccord exists by prefix name or not.
       *
       * \param  name    A prefix name value.
       * \return Return true if exists.
       */
-      bool isExistsByName(const QString prefix_name) const;
+    bool isExistsByName(const QString &prefix_name) const;
 
-      /*! \brief This function deletes all prefix fields by prefix_name keys value from table.
+    /*! \brief This function deletes all prefix fields by prefix_name keys value from table.
       *
       * \param  prefix_name        A prefix name value.
       * \param  prefix_path        A prefix path value.
@@ -112,16 +122,27 @@ class Prefix
       * \param  mountpoint_windrive The windows drive to use for this mountpoint
       * \return Return true on success.
       */
-      bool updatePrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString old_prefix_name, const QString arch, const QString mountpoint_windrive, const QString run_string, const QString version_id) const;
+    bool updatePrefix(const QString &prefix_name,
+                      const QString &prefix_path,
+                      const QString &wine_exec,
+                      const QString &wine_server,
+                      const QString &wine_loader,
+                      const QString &wine_dllpath,
+                      const QString &cdrom_mount,
+                      const QString &old_prefix_name,
+                      const QString &arch,
+                      const QString &mountpoint_windrive,
+                      const QString &run_string,
+                      const QString &version_id) const;
 
-      void fixPrefixPath();
+    void fixPrefixPath();
 protected:
-      /*! \brief This function executes requested query.
+    /*! \brief This function executes requested query.
       *
       * \param  SQL Query
       * \return Return true on success
       */
-      bool updateQuery(QSqlQuery *sqlQuery) const;
+    bool updateQuery(QSqlQuery *sqlQuery) const;
 
 };
 
