@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,7 +35,7 @@ HttpCore::HttpCore()
         libq4wine.load();
     }
 
-    // Getting corelib calss pointer
+    // Getting corelib class pointer
     CoreLibClassPointer = (CoreLibPrototype*) libq4wine.resolve("createCoreLib");
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
@@ -74,8 +74,9 @@ void HttpCore::getAppDBXMLPage(QString host, short int port, QString page)
 {
     this->page = page;
     if (!this->getCacheFile(page)){
-        QString url = QString("http://%1:%2/%3").arg(host, QString::number(port), page);
+        QString url = QString("https://%1:%2/%3").arg(host, QString::number(port), page);
         QNetworkRequest request = QNetworkRequest(QUrl(url));
+        request.setSslConfiguration(QSslConfiguration::defaultConfiguration());
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         request.setHeader(QNetworkRequest::UserAgentHeader, user_agent);
         http->get(request);
