@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -391,8 +391,8 @@ void XmlParser::parseComment(const QDomElement &element, WineAppDBInfo &appinfo)
 			comment.id = element.attribute("id").toInt();
 		} else if (node.toElement().tagName()=="date"){
 			comment.date = getChildNodeData(node.firstChild());
-		} else if (node.toElement().tagName()=="autor"){
-			comment.autor = getChildNodeData(node.firstChild());
+		} else if (node.toElement().tagName()=="author"){
+			comment.author = getChildNodeData(node.firstChild());
 		} else if (node.toElement().tagName()=="parent"){
 			comment.parent_id = getChildNodeData(node.firstChild()).toInt();
 		} else if (node.toElement().tagName()=="message"){
