@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2009 by Pavel Zinin (pashazz)                              *
  *   pzinin@gmail.com                                                     *
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,7 +20,7 @@
 
 #include "winetricks.h"
 
-winetricks::winetricks(QString prefixName) : QWidget()
+winetricks::winetricks(const QString &prefixName) : QWidget()
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
@@ -33,8 +33,8 @@ winetricks::winetricks(QString prefixName) : QWidget()
         libq4wine.load();
     }
 
-    // Getting corelib calss pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    // Getting corelib class pointer
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     this->winetricks_bin = QDir::homePath();
@@ -113,7 +113,7 @@ bool winetricks::check_script(bool warn){
     return true;
 }
 
-void winetricks::run_winetricks(QString item){
+void winetricks::run_winetricks(const QString &item){
     if (!check_script())
         return;
 
@@ -124,25 +124,26 @@ void winetricks::run_winetricks(QString item){
     qDebug()<<"[plugin] run item";
 #endif
 
-   QStringList args;
-        if (!console_args.isEmpty()){
-                // If we have any conslope parametres, we gona preccess them one by one
-                QStringList cons_args = console_args.split(" ");
-                for (int i=0; i<cons_args.count(); i++){
-                        if (!cons_args.at(i).isEmpty())
-                                args.append(cons_args.at(i));
-                }
+    QStringList args;
+    if (!console_args.isEmpty()){
+        // If we have any conslope parametres, we gona preccess them one by one
+        QStringList cons_args = console_args.split(" ");
+        for (int i=0; i<cons_args.count(); i++){
+            if (!cons_args.at(i).isEmpty())
+                args.append(cons_args.at(i));
         }
+    }
 
-        if (console_bin.split("/").last() == "konsole"){
-            args.append("/bin/sh");
-            args.append("-c");
-        }
+    QString console_last = console_bin.split("/").last();
+    if ((console_last == "konsole") || (console_last == "st") || (console_last == "stterm")){
+        args.append("/bin/sh");
+        args.append("-c");
+    }
 
-        args.append(get_command(item).join(" "));
+    args.append(get_command(item).join(" "));
 
 #ifdef DEBUG
-        qDebug()<<"[DD] winetricks args: "<<args;
+    qDebug()<<"[DD] winetricks args: "<<args;
 #endif
 
     QProcess proc;
@@ -151,7 +152,7 @@ void winetricks::run_winetricks(QString item){
     return;
 }
 
-QStringList winetricks::get_command(QString item){
+QStringList winetricks::get_command(const QString &item){
     QStringList sh_args;
     int proxy_type = CoreLib->getSetting("network", "type", false, 0).toInt();
     sh_args.append("env");
@@ -211,6 +212,7 @@ QStringList winetricks::get_command(QString item){
     sh_args.append(CoreLib->getWhichOut("sh"));
     sh_args.append("-c");
     sh_args.append(QString("\"%1 --no-isolate %2\"").arg(this->winetricks_bin).arg(item));
+    sh_args.append("; echo '== Press Enter to Close =='; read n");
     return sh_args;
 }
 
@@ -283,13 +285,13 @@ void winetricks::downloadwinetricks () {
     args.append(arg);
 
 #ifdef DEBUG
-        qDebug()<<"[DD] winetricks exec: "<<console_bin<<args;
+    qDebug()<<"[DD] winetricks exec: "<<console_bin<<args;
 #endif
     QProcess proc(this);
     proc.startDetached(console_bin, args);
-    #ifdef DEBUG
+#ifdef DEBUG
     qDebug()<<"[plugin] download done";
-    #endif
+#endif
     return;
 }
 
@@ -305,9 +307,9 @@ bool winetricks::parse() {
     pd->setValue(1);
     QCoreApplication::processEvents(QEventLoop::WaitForMoreEvents, 100);
 
-    #ifdef DEBUG
-        qDebug()<<"[plugin] parsing winetricks script";
-    #endif
+#ifdef DEBUG
+    qDebug()<<"[plugin] parsing winetricks script";
+#endif
 
     pd->setLabelText(tr("Dropping stale items..."));
     db_sysconfig.begin();
@@ -387,7 +389,7 @@ bool winetricks::parse() {
             desc += " (" + verb["publisher"] + ", " + verb["year"] + ")";
         qstring_map::const_iterator const it_media = verb.find("media");
         if (it_media != verb.end() && verb["media"] == "download")
-          desc += " [downloadable]";  // TODO: "cached" flag
+            desc += " [downloadable]";  // TODO: "cached" flag
         pd->setValue(90 * added_verb / all_verbs + 10);
         pd->setLabelText(tr("Adding verb: %1").arg(name));
         db_sysconfig.add_item(verb["name"], "application-x-ms-dos-executable", desc, verb["category"], D_PROVIDER_WINETRICKS, installed_apps.contains(verb["name"]));
@@ -399,9 +401,9 @@ bool winetricks::parse() {
 
     db_sysconfig.vacuum();
 
-    #ifdef DEBUG
-        qDebug()<<"[plugin] parsing winetricks script done";
-    #endif
+#ifdef DEBUG
+    qDebug()<<"[plugin] parsing winetricks script done";
+#endif
 
     pd->setValue(100);
 
