@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -46,8 +46,8 @@ int main(int argc, char *argv[])
         return -1;
     }
 
-    // Getting corelib calss pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    // Getting corelib class pointer
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(false)));
 
     QTranslator qtt;
@@ -103,7 +103,7 @@ int main(int argc, char *argv[])
         }
         if ((app.arguments().at(i)=="--version") or (app.arguments().at(i)=="-v")){
             Qcout<<QString("%1-cli %2").arg(APP_SHORT_NAME).arg(APP_VERS)<<endl;
-            Qcout<<QString("Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>")<<endl;
+            Qcout<<QString("Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>")<<endl;
             Qcout<<QString("License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.")<<endl;
             Qcout<<QObject::tr("This is free software: you are free to change and redistribute it.")<<endl;
             Qcout<<QObject::tr("There is NO WARRANTY, to the extent permitted by law.")<<endl;
