@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,8 +31,8 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
         libq4wine.load();
     }
 
-    // Getting corelib calss pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    // Getting corelib class pointer
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     setupUi(this);
@@ -225,6 +225,12 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
         cbUseSingleClick->setChecked(true);
     }
 
+    if (settings.value("hideArguments", 0).toInt()==0){
+        cbHideArguments->setChecked(false);
+    } else {
+        cbHideArguments->setChecked(true);
+    }
+
     if (settings.value("useNativeFileDialog", 1).toInt()==1){
         cbUseNativeDialog->setChecked(true);
     } else {
@@ -659,6 +665,12 @@ void AppSettings::cmdOk_Click(){
         settings.setValue("useSingleClick", 0);
     }
 
+    if (cbHideArguments->isChecked()){
+        settings.setValue("hideArguments", 1);
+    } else {
+        settings.setValue("hideArguments", 0);
+    }
+
     if (cbUseNativeDialog->isChecked()){
         settings.setValue("useNativeFileDialog", 1);
     } else {
