@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -41,8 +41,8 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
         libq4wine.load();
     }
 
-    // Getting corelib calss pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    // Getting corelib class pointer
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     this->prefix_name = prefix_name;
@@ -66,6 +66,9 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
     if (QDir(this->prefix_path).exists())
        prefix_urls << QUrl::fromLocalFile(this->prefix_path);
 
+    if ((!txtWorkDir->text().isEmpty()) and (QDir(txtWorkDir->text()).exists()))
+       prefix_urls << QUrl::fromLocalFile(txtWorkDir->text());
+
     QString cd_mount = result.value("mount");
 
     if (!cd_mount.isEmpty())
@@ -240,6 +243,14 @@ void IconSettings::getIconReccord(){
     return;
 }
 
+void IconSettings::updateSidebarUrls( QFileDialog *dialog )
+{
+   if ((!txtWorkDir->text().isEmpty()) and (QDir(txtWorkDir->text()).exists())) {
+      prefix_urls << QUrl::fromLocalFile(txtWorkDir->text());
+   }
+   dialog->setSidebarUrls(prefix_urls);
+}
+
 bool IconSettings::eventFilter( QObject *object, QEvent *event )
 {
    //  firstly, check whether the object is the QTableWidget and if it's a mouse press event
@@ -302,6 +313,8 @@ void IconSettings::cmdGetWorkDir_Click(){
       dialog.setWindowTitle(tr("Open Directory"));
       dialog.setDirectory(searchPath);
 
+      this->updateSidebarUrls(&dialog);
+
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
@@ -355,6 +368,8 @@ void IconSettings::cmdGetProgram_Click(){
       dialog.setFileMode(QFileDialog::ExistingFile);
       dialog.setNameFilter(tr("Exe, MSI, BAT files (*.exe *.EXE *.msi *.MSI *.bat *.BAT);;Exe files (*.exe *.EXE);;MSI files (*.msi *.MSI);;BAT files (*.bat *.BAT);;All files (*)"));
 
+      this->updateSidebarUrls(&dialog);
+
       if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
           dialog.setOptions(QFileDialog::DontUseNativeDialog);
       }
@@ -422,12 +437,13 @@ void IconSettings::cmdGetIcon_Click(){
       }
       dialog.setDirectory(searchPath);
 
+      this->updateSidebarUrls(&dialog);
+
         #ifndef WITH_ICOUTILS
         dialog.setNameFilter(tr("Image files (*.png *.PNG *.jpg *.JPG *.gif *.GIF *.bmp *.BMP *.xpm *.XPM *.svg *.SVG *.svgz *.SVGZ)"));
         #else
         dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.PNG *.jpg *.JPG *.gif *.GIF *.bmp *.BMP *.xpm *.XPM *.exe *.EXE *.dll *.DLL);;Image files (*.png *.PNG *.jpg *.JPG *.gif *.GIF *.bmp *.BMP *.xpm *.XPM *.svg *.SVG *.svgz *.SVGZ);;Win32 Executable (*.exe *.EXE);;Win32 Shared libraries (*.dll *.DLL);;Win32 Executable and Shared libraries (*.exe *.EXE *.dll *.DLL);;All files (*)"));
         #endif
-      //dialog.setSidebarUrls(add_prefix_urls);
 
      if (dialog.exec())
         fileName = dialog.selectedFiles().first();
@@ -441,63 +457,47 @@ void IconSettings::cmdGetIcon_Click(){
             args << "-x";
             args << "-t" << "14";
 
-            QString tmpDir="";
-            QStringList list1 = fileName.split("/");
+            QTemporaryDir tmpDir;
+            tmpDir.setAutoRemove(false);
+            if (tmpDir.isValid()) {
+                QString tmpDirPath = tmpDir.path();
+                qDebug() << "Using tmp path:" << tmpDirPath;
+                args << "-o" << tmpDirPath;
+                args << fileName;
 
-            tmpDir.append(QDir::homePath());
-            tmpDir.append("/.config/");
-            tmpDir.append(APP_SHORT_NAME);
-            tmpDir.append("/tmp/");
-            tmpDir.append(list1.last());
+                Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
+                if (exportProcess.exec()==QDialog::Accepted){
+                    // Updating file index
+                    QStringList nameFilters;
+                    nameFilters << "*.ico";
+                    QFileInfoList icoFilesList = QDir(tmpDirPath).entryInfoList(nameFilters, QDir::Files | QDir::Hidden | QDir::NoSymLinks);
+                    if (icoFilesList.size() > 0) {
+                        //icotool -x -o ./regedit.png --width=32 --height=32 ./regedit.exe_14_100_0.ico
+                        args.clear();
+                        args << "-x";
+                        //Creating file list for converting
+                        for (int i = 0; i < icoFilesList.size(); ++i) {
+                            QFileInfo fileInfo = icoFilesList.at(i);
+                            qDebug() << fileInfo.fileName();
+                            args << fileInfo.filePath();
+                        }
+                        args << "-o" << QString("%1/").arg(tmpDirPath);
 
-            QDir tmp(tmpDir);
-            tmp.setFilter(QDir::Files | QDir::Hidden | QDir::NoSymLinks);
-            QFileInfoList list = tmp.entryInfoList();
-
-            if (tmp.exists(tmpDir)){
-                for (int i = 0; i < list.size(); ++i) {
-                    QFileInfo fileInfo = list.at(i);
-                    if (!tmp.remove(fileInfo.filePath()))
-                        qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
-                }
-            } else {
-                if (!tmp.mkdir(tmpDir)){
-                    qDebug()<<"[EE] - Cannot create temp directory at: "<<tmpDir;
-                }
-            }
-
-            args << "-o" << tmpDir;
-            args << fileName;
-
-            Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
-
-            if (exportProcess.exec()==QDialog::Accepted){
-            //icotool -x -o ./regedit.png --width=32 --height=32 ./regedit.exe_14_100_0.ico
-                args.clear();
-                args << "-x";
-
-                QDir ico_dir(tmpDir);
-                // Updating file index
-                list = ico_dir.entryInfoList();
-
-                //Creating file list for converting
-                for (int i = 0; i < list.size(); ++i) {
-                    QFileInfo fileInfo = list.at(i);
-                    qDebug() << fileInfo.fileName();
-                    if (fileInfo.fileName().right(3)=="ico")
-                        args << fileInfo.filePath();
-                }
-
-                args << "-o" << QString("%1/").arg(tmpDir);
-
-                //Converting ico files to png
-
-                //Look here, this function checks if some icons found, or not. 5 -- is default number of arguments,
-                //if more -- then we have some ico file to convert
-                if (args.size()>=4){
-                    Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
-                    if (exportProcess.exec()==QDialog::Accepted){
-                        IconsView iconsView(tmpDir);
+                        //Converting ico files to png
+                        Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
+                        if (exportProcess.exec()==QDialog::Accepted){
+                            IconsView iconsView(tmpDirPath);
+                            if (iconsView.exec()==QDialog::Accepted){
+                                fileName=iconsView.selectedFile;
+                                cmdGetIcon->setIcon(QIcon(fileName));
+                                qDebug()<<"Selected:"<<fileName;
+                            } else {
+                                fileName.clear();
+                            }
+                        }
+                    } else {
+                        qDebug() << "[WW] No ico files found.";
+                        IconsView iconsView(tmpDirPath);
                         if (iconsView.exec()==QDialog::Accepted){
                             fileName=iconsView.selectedFile;
                             cmdGetIcon->setIcon(QIcon(fileName));
@@ -505,34 +505,10 @@ void IconSettings::cmdGetIcon_Click(){
                             fileName.clear();
                         }
                     }
-                } else {
-                    IconsView iconsView(tmpDir);
-                    if (iconsView.exec()==QDialog::Accepted){
-                        fileName=iconsView.selectedFile;
-                        cmdGetIcon->setIcon(QIcon(fileName));
-                    } else {
-                        fileName.clear();
-                    }
                 }
-            } else {
-                qDebug()<<"wrestool testing Rejected";
-                fileName.clear();
+                tmpDir.remove();
             }
-
-            //Clearing temp files
-            list = tmp.entryInfoList();
-
-                //Creating file list for converting
-            for (int i = 0; i < list.size(); ++i) {
-                QFileInfo fileInfo = list.at(i);
-                    if (!QFile::remove(fileInfo.filePath()))
-                        qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
-            }
-
-            if (!tmp.rmdir(tmpDir))
-                qDebug()<<"[EE] - Cannot delete tmp dir: "<<tmpDir;
         }
-
         if (!fileName.isEmpty())
             iconPath=fileName;
     }
