@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -43,6 +43,7 @@
 #include <QKeyEvent>
 #include <QHeaderView>
 #include <QTableWidgetItem>
+#include <QTemporaryDir>
 
 #include "q4wine-lib.h"
 
@@ -121,8 +122,9 @@ class IconSettings : public QDialog, public Ui::IconSettings
 
         //! Side bar URLs list.
         QList<QUrl> prefix_urls;
+        void updateSidebarUrls(QFileDialog *dialog);
 
-        //! Database prefix class defenition.
+        //! Database prefix class definition.
         Prefix db_prefix;
         Icon db_icon;
 
