@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,8 +18,8 @@
 
 #include "mainwindow.h"
 
-MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt::WindowFlags f) : QMainWindow(parent, f){
-     // Loading libq4wine-core.so
+MainWindow::MainWindow(const int startState, const QString &run_binary, QWidget * parent, const Qt::WindowFlags f) : QMainWindow(parent, f){
+    // Loading libq4wine-core.so
 #ifdef RELEASE
     libq4wine.setFileName(_CORELIB_PATH_);
 #else
@@ -30,7 +30,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     }
 
     // Getting corelib class pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     clearTmp();
@@ -51,7 +51,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     if (!this->createSocket()){
         this->close();
         return;
-     }
+    }
 
     if (startState == 1)
         this->showMinimized();
@@ -220,7 +220,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
 }
 
 void MainWindow::setSearchFocus(){
-//    txtIconFilter->setFocus(Qt::OtherFocusReason);
+    //    txtIconFilter->setFocus(Qt::OtherFocusReason);
     return;
 }
 
@@ -253,7 +253,7 @@ void MainWindow::trayIcon_Activate(QSystemTrayIcon::ActivationReason reason){
     return;
 }
 
-void MainWindow::updateIconDesc(QString program, QString args, QString desc, QString console, QString desktop){
+void MainWindow::updateIconDesc(const QString &program, QString args, const QString &desc, const QString &console, const QString &desktop){
     /*
      * This is function for selection icons, and displaying
      * icon informationm like path and description
@@ -266,7 +266,18 @@ void MainWindow::updateIconDesc(QString program, QString args, QString desc, QSt
         args=strip_arg;
     }
 
-    lblIconInfo0->setText(tr("Program: %1<br> Args: %2 ").arg(program) .arg(args));
+    QString iconInfo = QString(tr("Program: %1").arg(program));
+    iconInfo.append("<br>");
+        if (!CoreLib->getSetting("advanced", "hideArguments", false).toBool()){
+        iconInfo.append(QString(tr("Args: %1").arg(args)));
+    } else {
+        if (!args.isEmpty()) {
+            iconInfo.append(QString(tr("Args: %1").arg(tr("hidden"))));
+        } else {
+            iconInfo.append(QString(tr("Args: %1").arg("")));
+        };
+    };
+    lblIconInfo0->setText(iconInfo);
     lblIconInfo2->setText(tr("Description: %1").arg(desc));
 
     QString useconsole="";
@@ -331,7 +342,7 @@ void MainWindow::getSettings(){
     return;
 }
 
-void MainWindow::changeStatusText(QString text){
+void MainWindow::changeStatusText(const QString &text){
     statusBar()->showMessage(text);
 }
 
@@ -341,7 +352,7 @@ void MainWindow::updateDtabaseConnectedItems(){
 }
 
 #ifdef WITH_WINEAPPDB
-void MainWindow::searchRequest(QString search){
+void MainWindow::searchRequest(const QString &search){
     tbwGeneral->setCurrentIndex (4);
     emit(appdbWidget_startSearch(1, search));
 }
@@ -415,8 +426,8 @@ void MainWindow::newConnection (){
 
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
                             if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
-                        }
+                                this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            }
 
                         emit(reloadLogData());
 
@@ -428,9 +439,9 @@ void MainWindow::newConnection (){
                         this->changeStatusText(tr("Console started fine for Application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
 
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
-                        if ((this->isHidden() || this->isMinimized()) && (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
-                        }
+                            if ((this->isHidden() || this->isMinimized()) && (trayIcon->isVisible())){
+                                this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            }
 
                         emit(reloadLogData());
 
@@ -441,9 +452,9 @@ void MainWindow::newConnection (){
                     if (list.count()==4){
                         this->changeStatusText(tr("Application: \"%1\" finished for prefix: \"%2\". Exit code is: \"%3\".").arg(list.at(1)).arg(list.at(2)).arg(list.at(3)));
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
-                        if ((this->isHidden() || this->isMinimized()) && trayIcon->isVisible()){
-                            this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" finished for prefix: \"%2\". Exit code is: \"%3\".").arg(list.at(1)).arg(list.at(2)).arg(list.at(3)));
-                        }
+                            if ((this->isHidden() || this->isMinimized()) && trayIcon->isVisible()){
+                                this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" finished for prefix: \"%2\". Exit code is: \"%3\".").arg(list.at(1)).arg(list.at(2)).arg(list.at(3)));
+                            }
 
                         emit(reloadLogData());
                     } else {
@@ -453,9 +464,9 @@ void MainWindow::newConnection (){
                     if (list.count()==3){
                         this->changeStatusText(tr("Cannot start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
-                        if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notification"), tr("Cannot start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
-                        }
+                            if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
+                                this->showNotifycation(tr("helper notification"), tr("Cannot start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            }
                     } else {
                         this->showSocketError(message);
                     }
@@ -463,10 +474,10 @@ void MainWindow::newConnection (){
                     if (list.count()==3){
                         this->changeStatusText(tr("Cannot start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
-                        if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notification"), tr("Cannot start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
+                                this->showNotifycation(tr("helper notification"), tr("Cannot start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
 
-                        }
+                            }
                     } else {
                         this->showSocketError(message);
                     }
@@ -537,7 +548,7 @@ void MainWindow::closeEvent(QCloseEvent *event){
     return;
 }
 
-void MainWindow::tbwGeneral_CurrentTabChange(int tabIndex){
+void MainWindow::tbwGeneral_CurrentTabChange(const int tabIndex){
 
     if (tabIndex==0){
         emit(stopProcTimer());
@@ -787,15 +798,15 @@ void MainWindow::mainExportIcons_Click(){
      * main Menu allow export icons
      */
 
-    QString fileName, tmpDir;
+    QString fileName;
     QStringList args;
 
-        QFileDialog::Options options;
+    QFileDialog::Options options;
 
-        if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
-                options = QFileDialog::DontUseNativeDialog;
+    if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
+        options = QFileDialog::DontUseNativeDialog;
 
-    fileName = QFileDialog::getOpenFileName(this, tr("Open image file"), QDir::homePath(), tr("Win32 Executable and Shared libraries (*.exe *.EXE *.dll *.DLL);;Win32 Executable (*.exe *.EXE);;Win32 Shared libraries (*.dll *.DLL);;All files (*)"), 0, options );
+    fileName = QFileDialog::getOpenFileName(this, tr("Open image file"), QDir::homePath(), tr("Win32 Executable and Shared libraries (*.exe *.EXE *.dll *.DLL);;Win32 Executable (*.exe *.EXE);;Win32 Shared libraries (*.dll *.DLL);;All files (*)"), nullptr, options );
 
     if(fileName.isEmpty())
         return;
@@ -803,114 +814,72 @@ void MainWindow::mainExportIcons_Click(){
     args << "-x";
     args << "-t" << "14";
 
-    QStringList list1 = fileName.split("/");
+    QTemporaryDir tmpDir;
+    tmpDir.setAutoRemove(false);
+    if (tmpDir.isValid()) {
+        QString tmpDirPath = tmpDir.path();
+        qDebug() << "Using tmp path:" << tmpDirPath;
+        args << "-o" << tmpDirPath;
+        args << fileName;
 
-    tmpDir.clear();
+        Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
+        if (exportProcess.exec()==QDialog::Accepted){
+            // Updating file index
+            QStringList nameFilters;
+            nameFilters << "*.ico";
+            QFileInfoList icoFilesList = QDir(tmpDirPath).entryInfoList(nameFilters, QDir::Files | QDir::Hidden | QDir::NoSymLinks);
+            if (icoFilesList.size() > 0) {
+                //icotool -x -o ./regedit.png --width=32 --height=32 ./regedit.exe_14_100_0.ico
+                args.clear();
+                args << "-x";
+                //Creating file list for converting
+                for (int i = 0; i < icoFilesList.size(); ++i) {
+                    QFileInfo fileInfo = icoFilesList.at(i);
+                    qDebug() << fileInfo.fileName();
+                    args << fileInfo.filePath();
+                }
+                args << "-o" << QString("%1/").arg(tmpDirPath);
 
-    tmpDir.append(QDir::homePath());
-    tmpDir.append("/.config/");
-    tmpDir.append(APP_SHORT_NAME);
-    tmpDir.append("/tmp/");
-    tmpDir.append(list1.last());
-
-    QDir tmp(tmpDir);
-    tmp.setFilter(QDir::Files | QDir::Hidden | QDir::NoSymLinks);
-    QFileInfoList list = tmp.entryInfoList();
-
-    if (tmp.exists(tmpDir)){
-        for (int i = 0; i < list.size(); ++i) {
-            QFileInfo fileInfo = list.at(i);
-            if (!tmp.remove(fileInfo.filePath()))
-                qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
-        }
-
-    } else {
-        if (!tmp.mkdir(tmpDir)){
-            qDebug()<<"[EE] - Cannot create temp directory at: "<<tmpDir;
-        }
-    }
-
-
-    args << "-o" << tmpDir;
-    args << fileName;
-
-    Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
-
-    if (exportProcess.exec()==QDialog::Accepted){
-        //icotool -x -o ./regedit.png --width=32 --height=32 ./regedit.exe_14_100_0.ico
-
-
-
-        args.clear();
-        args << "-x";
-        args << "-o" << QString("%1/").arg(tmpDir);
-
-        // Updating file index
-        list = tmp.entryInfoList();
-
-        //Creating file list for converting
-        for (int i = 0; i < list.size(); ++i) {
-            QFileInfo fileInfo = list.at(i);
-            if (fileInfo.fileName().right(3)=="ico")
-                args << fileInfo.filePath();
-        }
-
-
-        //Look here, this function checks if some icons found, or not. 5 -- is default number of arguments,
-        //if more -- then we have some ico file to convert
-        if (args.size()>=4){
-
-            Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
-
-            if (exportProcess.exec()==QDialog::Accepted){
-                IconsView iconsView(tmpDir);
+                //Converting ico files to png
+                Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
+                if (exportProcess.exec()==QDialog::Accepted){
+                    IconsView iconsView(tmpDirPath);
+                    iconsView.exec();
+                }
+            } else {
+                qDebug() << "[WW] No ico files found.";
+                IconsView iconsView(tmpDirPath);
                 iconsView.exec();
             }
-
-        } else {
-            IconsView iconsView(tmpDir);
-            iconsView.exec();
         }
+        tmpDir.remove();
     }
 
-    //Clearing temp files
-    list = tmp.entryInfoList();
-
-    //Creating file list for converting
-    for (int i = 0; i < list.size(); ++i) {
-        QFileInfo fileInfo = list.at(i);
-        if (!QFile::remove(fileInfo.filePath()))
-            qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
-    }
-
-    if (!tmp.rmdir(tmpDir))
-        qDebug()<<"[EE] - Cannot delete tmp dir: "<<tmpDir;
-
     return;
 }
 
 void MainWindow::mainHelpThisTab_Click(){
     QString rawurl="";
     switch (tbwGeneral->currentIndex()){
-case 0:
-       rawurl = "04-general-gui-description.html#programs";
-       break;
-case 1:
-       rawurl = "04-general-gui-description.html#process";
-       break;
-case 2:
-       rawurl = "04-general-gui-description.html#setup";
-       break;
-case 3:
-       rawurl = "04-general-gui-description.html#prefixes";
-       break;
-case 4:
-       rawurl = "04-general-gui-description.html#appdb";
-       break;
-case 5:
-       rawurl = "04-general-gui-description.html#logging";
-       break;
-   }
+    case 0:
+        rawurl = "04-general-gui-description.html#programs";
+        break;
+    case 1:
+        rawurl = "04-general-gui-description.html#process";
+        break;
+    case 2:
+        rawurl = "04-general-gui-description.html#setup";
+        break;
+    case 3:
+        rawurl = "04-general-gui-description.html#prefixes";
+        break;
+    case 4:
+        rawurl = "04-general-gui-description.html#appdb";
+        break;
+    case 5:
+        rawurl = "04-general-gui-description.html#logging";
+        break;
+    }
 
     CoreLib->openHelpUrl(rawurl);
     return;
@@ -955,7 +924,7 @@ void MainWindow::mainVersionManager_Click(){
     delete(vers);
 }
 
-void MainWindow::showNotifycation(const QString header, const QString message){
+void MainWindow::showNotifycation(const QString &header, const QString &message){
 #ifdef WITH_DBUS
     QVariantList args;
     args << QString(APP_NAME);
@@ -979,7 +948,7 @@ void MainWindow::showNotifycation(const QString header, const QString message){
 #endif
 }
 
-void MainWindow::messageReceived(const QString message){
+void MainWindow::messageReceived(const QString &message){
     if (message.isEmpty()){
         if (!isVisible())
             this->setMeVisible(true);
