@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,8 +32,8 @@ Progress::Progress(int action, QString path, QWidget * parent, Qt::WindowFlags f
           libq4wine.load();
     }
 
-    // Getting corelib calss pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    // Getting corelib class pointer
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     setWindowIcon(CoreLib->loadIcon(CoreLib->getSetting("app", "icon", false, "q4wine").toString()));
@@ -70,7 +70,7 @@ Progress::Progress(int action, QString path, QWidget * parent, Qt::WindowFlags f
 void Progress::cmdCancel_Click(){
     t->stop();
     if (action==0){
-        /* becouse, of desktop folder can contains user subdirs, DO NOT REMOVE this folders
+        /* because, of desktop folder can contains user subdirs, DO NOT REMOVE this folders
         if (CoreLib->getSetting("DesktopImport", "remove", false, 0)==1)
             removeEmptyFolders(this->path);
         */
@@ -86,7 +86,7 @@ void Progress::runAction(){
 #endif
         if ((current>=max) or (max==0)){
             t->stop();
-            /* becouse, of desktop folder can contains user subdirs, DO NOT REMOVE this folders
+            /* because, of desktop folder can contains user subdirs, DO NOT REMOVE this folders
             if (CoreLib->getSetting("DesktopImport", "remove", false, 0)==1)
                 removeEmptyFolders(this->path);
             */
