@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -54,7 +54,7 @@ signals:
 
 private:
 	void setTopic(QString topic, int type);
-	void setDate(QString autor, QString date);
+	void setDate(QString author, QString date);
 	void setMessage(QString message);
 	int id;
 	int parentid;
