@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -38,10 +38,10 @@ LineItemWidget::~LineItemWidget(){
     //nothig but...
 }
 
-void LineItemWidget::addLabel(const QString text, const short int width, const short int aligment, const bool worldwarp){
+void LineItemWidget::addLabel(const QString text, const short int width, const short int alignment, const bool worldwarp){
     std::unique_ptr<QLabel> label(new QLabel(this));
 
-    switch (aligment){
+    switch (alignment){
         case 0:
         label->setAlignment(Qt::AlignLeft);
         break;
