@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,8 +31,8 @@ IconListWidget::IconListWidget(QWidget *parent) : QListWidget (parent)
         libq4wine.load();
     }
 
-    // Getting corelib calss pointer
-    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    // Getting corelib class pointer
+    CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     setResizeMode(QListView::Adjust);
@@ -89,7 +89,7 @@ void IconListWidget::showContents(QString filterString){
         iconItem->setText(iconsList.at(i));
         iconItem->setToolTip(iconsList.at(i));
 
-        //Seting icon. If no icon or icon file does not exist -- setting default
+        //Setting icon. If no icon or icon file does not exist -- setting default
         QString icon_path = db_icon.getPixmapIcon(this->prefixName, this->dirName, iconsList.at(i));
         if (icon_path.isEmpty()){
             iconItem->setIcon(defIcon);
@@ -194,7 +194,7 @@ void IconListWidget::startDrag(){
         std::unique_ptr<QDrag> drag(new QDrag(this));
         drag->setMimeData(mimeData.release());
         drag->setPixmap(items.at(0)->icon().pixmap(32));
-        drag->start(Qt::MoveAction);
+        drag->exec(Qt::MoveAction);
         drag.release();
     }
 #endif
@@ -809,7 +809,7 @@ void IconListWidget::iconRun_Click(void){
 void IconListWidget::iconCut_Click(void){
     /*
             This function fill iconBuffer with selected icons names
-            and sets other informations required for copy\cut
+            and sets other information required for copy\cut
 
             see struct iconCopyBuffer definition for details
       */
@@ -847,7 +847,7 @@ void IconListWidget::iconCut_Click(void){
 void IconListWidget::iconCopy_Click(void){
     /*
       * This function fill iconBuffer with selected icons names
-      * and sets other informations required for copy\cut
+      * and sets other information required for copy\cut
       *
       * see struct iconCopyBuffer definition for details
       */
